import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import PasswordBody from './PasswordBoxBody';
import classNames from 'classnames'

export default forwardRef((props, ref) => {
    const inputRef = useRef();
    const { value, className } = props;
    const nativeClass = classNames(`lm-pwd-cont`, `lm-password-box-def`, `${className}`);

    /*
    * 获取input value
    * callback value
    * */
    const handleChange = (e) => {
        e.preventDefault();
        let _passwordLen = props.passwordLen;
        let _value = e.target.value;
        if(_value.length > _passwordLen) {
            _value = _value.slice(0, _passwordLen);
        }

        props.onChange(_value);
    }

    /*
    * input dom 失去焦点
    * */
    useImperativeHandle(ref, () => ({
        onhandleBlur: () => {
            inputRef && inputRef.current && inputRef.current.blur();
        },
    }), [inputRef]);

    return (
        <section className={ nativeClass }>
            <input
                className="lm-pwd-input"
                type={ props.inputType }
                value={value}
                maxLength={ props.passwordLen }
                ref={inputRef}
                onChange={ handleChange }
                onFocus={ props.onClick }
            />

            <PasswordBody
                value={ value }
                passwordLen={ props.passwordLen }
                isEncrypt={ props.isEncrypt }
                hasAnimation={ props.hasAnimation }
                hasError={ props.hasError }
                classConfig={ props.classConfig }
                contentType={ props.contentType }
                animationDuration={ props.animationDuration }
            />
        </section>
    )

})
