import React from 'react';
import classNames from 'classnames';

class PasswordBoxItem extends React.PureComponent {

    render() {

        let {
            isEncrypt,
            itemVal,
            hasError,
            classConfig,
            contentType,
            animationDuration
        } = this.props;

        let { usualClass='', errorClass='' } = classConfig;
        let pwdItemContClassName = !hasError ? classNames('lm-pwd-item', `${usualClass}`) :
            classNames('lm-pwd-item', `${usualClass}`, `${errorClass}`);

        let compParams = {
            itemVal: itemVal,
            contentType: contentType,
            className: pwdItemContClassName,
            isEncrypt: isEncrypt,
            animationDuration: animationDuration
        }

        return(
            this.props.hasAnimation ?
                <HasAnimation
                    {...compParams}
                /> : <NoAnimation
                {...compParams}
            />

        )
    }

}


// 无动画
function NoAnimation (props) {

    if(props.isEncrypt && props.itemVal.length){
        return(
            <EncrypteIcon
                encrypteType={ props.contentType }
                className={ props.className }

            />
        )
    }else{
        return (
            <Unencrypted
                encrypteType={ props.contentType }
                className={ props.className }
                itemVal={ props.itemVal }
            />
        )
    }

}

// 有动画
class HasAnimation extends React.PureComponent {

    stTimer = null  // 定时器标识

    constructor(props) {
        super(props);

        this.state = {
            itemVal: ''
        }
    }

    componentDidMount() {
        let {itemVal = ''} = this.props;
        this.setState({
            itemVal: itemVal
        })
    }

    getPwdItemVal = (val = '',cb = () => {}) => {
        this.setState({
            itemVal: val
        }, () => {
            cb();
        })
    }


    componentWillReceiveProps(nextProps) {
        let curVal = nextProps.itemVal;
        let animationDuration = nextProps.animationDuration;

        if(!nextProps.isEncrypt){
            this.getPwdItemVal(curVal)
        }else if(this.props.itemVal !== nextProps.itemVal) {
            let curVal = nextProps.itemVal;
            clearTimeout(this.stTimer)
            this.getPwdItemVal(curVal,() => {
                if(curVal.length>0) {
                    this.stTimer = setTimeout(() => {
                        this.getPwdItemVal('.')
                    }, animationDuration)
                }
            })
        }else{
            if(curVal.length > 0) {
                this.getPwdItemVal('.')
            }
        }
    }

    componentWillUnmount() {
        clearTimeout(this.stTimer)
    }

    render() {

        let { itemVal } = this.state;

        if(itemVal === '.'){
            return(
                <EncrypteIcon
                    encrypteType={ this.props.contentType }
                    className={ this.props.className }

                />
            )
        }else {
            return(
                <Unencrypted
                    encrypteType={ this.props.contentType }
                    className={ this.props.className }
                    itemVal={ itemVal }

                />
            )
        }

    }

}

function Unencrypted (props){

    let { itemVal } = props;
    return <span className={ 'lm-pwd-item' }>
                <span
                    className={"lm-pwd-item-num"}
                >{
                    itemVal === '' ? '' : itemVal
                }</span>
            </span>
}

function EncrypteIcon (props) {

    let {encrypteType} = props;

    return <span className={ props.className }>
                {
                    encrypteType === 'star' ?
                        <span className={"lm-pwd-item-num"}>*</span>
                        :
                        <span className={"lm-pwd-item-icon"}> </span>

                }
            </span>
}

export default PasswordBoxItem

