/**
 * Created by zhaojianling<zhaojianling@58ganji.com>.
 * ComponentName Password_box
 * Desc 密码框
 * GroupName lm-component
 */

import React, { forwardRef, useState } from 'react'
import PropTypes from 'prop-types'

import classNames from 'classnames'
import './polyfill';

import CustormPasswordBox from './CustormPasswordBox';
import NativePasswordBox from './NativePasswordBox';
import EyeButton from './EyeButton'

import './index.scss';

/**
 * @class Password_box
 * @extends React.Component
 * @desc Password_box Component for mobile
 */
const PasswordBox = (props, ref) => {
    const {
        keyboardType,
        className,
        hasEyeButton,
        styleType,
        eyePos
    } = props;

    const [isEncrypt, setIsEncrypt] = useState(props.isEncrypt);

    const handleEyeButtonClick = () => {
        let _curIsEncryptValue = isEncrypt;

        setIsEncrypt(!_curIsEncryptValue);
    }

    let passwordBoxClass = classNames('lm-password-box', `lm-password-type-${styleType}`);

    if(hasEyeButton){
        passwordBoxClass = classNames(`${passwordBoxClass}`, `eye-pos-${eyePos}`);
    }

    return (
        <section className={ passwordBoxClass }>
            {
                keyboardType === 'native' ?
                    <NativePasswordBox
                        ref={ref}
                        className={ className }
                        value={ props.password }
                        passwordLen={ props.passwordLen }
                        inputType={ props.inputType }
                        isEncrypt={ isEncrypt }
                        hasAnimation={ props.hasAnimation }
                        onChange={ props.onChange }
                        onClick={ props.onClick }
                        hasError={ props.hasError }
                        classConfig={ props.classConfig }
                        contentType={ props.contentType }
                        animationDuration={ props.animationDuration }

                    />
                    :
                    <CustormPasswordBox
                        className={ className }
                        value={ props.password }
                        passwordLen={ props.passwordLen }
                        isEncrypt={ isEncrypt }
                        hasAnimation={ props.hasAnimation }
                        onClick={ props.onClick }

                        hasError={ props.hasError }
                        classConfig={ props.classConfig }
                        contentType={ props.contentType }
                        animationDuration={ props.animationDuration }

                    />
            }

            {
                hasEyeButton ? <EyeButton
                    isEncrypt={ isEncrypt }
                    eyeButtonClassName={props.eyeButtonClassName}
                    handleEyeButtonClick={ handleEyeButtonClick }
                /> : null
            }

        </section>
    )

}


const ForwardPasswordBox = forwardRef(PasswordBox);

ForwardPasswordBox.propTypes = {
    keyboardType: PropTypes.oneOf(['native', 'custorm']),     // 键盘类型    native || custorm
    password: PropTypes.string,         // 密码值
    passwordLen: PropTypes.number,      // 密码长度
    inputType: PropTypes.string,        // input type(keyboardType 为native 时有效)
    isEncrypt: PropTypes.bool,          // 是否加密
    hasAnimation: PropTypes.bool,       // 是否有动画
    className: PropTypes.string,        // 自定义组件类名
    onChange: PropTypes.func,           // 回调函数（keyboardType为native时用于父组件获取键盘输入值）
    onClick: PropTypes.func,            // 点击密码框时回调函数

    hasError: PropTypes.bool,           // 输入是否有错
    hasEyeButton: PropTypes.bool,       // 是否显示眼睛按钮
    eyeButtonClassName: PropTypes.object,  // 眼睛按钮的类名
    eyePos: PropTypes.oneOf(['right', 'bottom']),       // 眼睛位置
    styleType: PropTypes.oneOf(['box', 'underline']),   // 密码框的展示类型
    classConfig: PropTypes.object,      // 样式配置{usualClass: '', errorClass: ''}
    contentType: PropTypes.oneOf(['circle', 'star']),       // 内容类型
    animationDuration: PropTypes.number  // 完成动画所花费的时间，以毫秒计
}


ForwardPasswordBox.defaultProps = {
    keyboardType: 'custorm',
    password: '',
    passwordLen: 6,
    inputType: 'number',
    isEncrypt: true,
    hasAnimation: false,
    className: '',
    onChange: () => {},
    onClick: () => {},

    hasError: false,
    eyeButtonClassName: {
        openEyeClass: '',
        closeEyeClass: ''
    },
    hasEyeButton: false,
    eyePos: 'right',
    styleType: 'box',
    classConfig: {
        usualClass: '',
        errorClass: ''
    },
    contentType: 'circle',
    animationDuration: 300,
};


export default ForwardPasswordBox;
